package hero.ra.config;

/**
 *
 * Bonita
 * Copyright (C) 1999 Bull S.A.
 * Bull 68 route de versailles  78434 Louveciennes Cedex France
 * Further information: bonita@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *
 --------------------------------------------------------------------------
 * $Id$
 *
 --------------------------------------------------------------------------
 */

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.util.Properties;

import org.apache.log4j.Level;
import org.apache.log4j.Logger;

import hero.interfaces.Constants;
import hero.ra.BonitaService;
import hero.user.ReadEnv;
import hero.util.ServerType;


public class Config implements BonitaService, ConfigMBean
{
	private Properties bonitaConfig = new Properties();
	private String bonitaHome = null;
	private boolean jms = true;
	private String historic = Constants.TRANSFER;
	private boolean jabberEnabled = false;
	private String jabberPassword = null;
	private int jabberPort = 0;
	private String jabberHost = null;
	private String jabberUser = null;
	private static final Logger log = Logger.getLogger("log");
	private Properties log4jConfig = new Properties();
	private String log4jConfigPath = null;
	private String logLevel = Constants.INFO;
	private String serverBase = null;
	private static final Logger trace =	Logger.getLogger("hero");
	private String traceLevel = Constants.INFO;
	
	public void startService() throws Exception
	{
		ReadEnv re = new ReadEnv();
		this.bonitaHome = re.getVariable("BONITA_HOME");
		bonitaConfig.load(new FileInputStream(bonitaHome+File.separator+".ant.properties"));
		
		String jms = (String)bonitaConfig.getProperty("bonita.Jms");
		if (jms.equalsIgnoreCase("true") || jms.equalsIgnoreCase("false"))
		{
			this.jms = new Boolean(jms).booleanValue();
		}
		else
		{
			this.jms = true;
		    throw new Exception("Error while setting config values, please check your BONITA_HOME/.ant.properties file");
		}
		
		String historic = (String)bonitaConfig.getProperty("bonita.Historic");
		if (historic.equalsIgnoreCase(Constants.TRANSFER) || historic.equalsIgnoreCase(Constants.PURGE))
		{
			this.historic = historic;
		}
		else
		{
			this.historic=Constants.TRANSFER;
		    throw new Exception("Error while setting config values, please check your BONITA_HOME/.ant.properties file");
		}
		
		jabberEnabled =  new Boolean((String)bonitaConfig.getProperty("jabber.enabled")).booleanValue();  
		jabberPassword = (String)bonitaConfig.getProperty("jabber.password");
		jabberPort =     Integer.parseInt((String)bonitaConfig.getProperty("jabber.port"));
		jabberHost =     (String)bonitaConfig.getProperty("jabber.host");
		jabberUser =     (String)bonitaConfig.getProperty("jabber.user");
		
		if(ServerType.isJonas())
		{
			this.log4jConfigPath = re.getVariable("JONAS_BASE")+File.separator+"conf"+File.separator+"log4j.properties";
		}
		else if(ServerType.isJBoss())
		{
			this.log4jConfigPath = re.getVariable("JBOSS_HOME")+File.separator+"server"+File.separator+"default"+File.separator+"conf"+File.separator+"log4j.properties";
		}
		else
		{
			throw new Exception("The Application Server is not supported");
		}
		log4jConfig.load(new FileInputStream(log4jConfigPath));
		
		String traceLevel = (String)log4jConfig.getProperty("log4j.logger.hero");
		int index = traceLevel.indexOf(",");
		traceLevel = traceLevel.substring(0,index);
		if (traceLevel.equalsIgnoreCase(Constants.DEBUG) || traceLevel.equalsIgnoreCase(Constants.INFO) || traceLevel.equalsIgnoreCase(Constants.ERROR))
			this.traceLevel=traceLevel;
		else
		{
			this.traceLevel=Constants.INFO;
		    throw new Exception("Error while setting config values, please check your BONITA_HOME/.ant.properties file");
		}
		
		String logLevel = (String)log4jConfig.getProperty("log4j.logger.log");
		index = logLevel.indexOf(",");
		logLevel = logLevel.substring(0,index);
		if (logLevel.equalsIgnoreCase(Constants.DEBUG) || logLevel.equalsIgnoreCase(Constants.INFO) || logLevel.equalsIgnoreCase(Constants.ERROR))				
			this.logLevel=logLevel;
		else
		{
			this.logLevel=Constants.INFO;
		    throw new Exception("Error while setting config values, please check your BONITA_HOME/.ant.properties file");
		}
	}
	
	public void stopService()
	{
	}
	
	public boolean getJabberEnabled()
	{
		return jabberEnabled;
	}
	
	public String getJabberHost()
	{
		return jabberHost;
	}
	
	public String getJabberPassword()
	{
		return jabberPassword;
	}
	
	public int getJabberPort()
	{
		return jabberPort;
	}
		
	public String getJabberUser()
	{
		return jabberUser;
	}
		
	public boolean getJms()
	{
		return (this.jms);
	}

	public String getLogLevel()
	{
		return (this.logLevel);
	}

	public String getTraceLevel()
	{
		return (this.traceLevel);
	}

	public String getHistoric()
	{
		return (this.historic);
	}
	
	public void updateJabberEnabled(boolean enabled) throws Exception
	{
		try {
			this.jabberEnabled=enabled;
			bonitaConfig.setProperty("jabber.enabled",new Boolean(enabled).toString());
			bonitaConfig.save(new FileOutputStream(this.bonitaHome+File.separator+".ant.properties"),null);
		}catch (Exception ex){
			throw new Exception("Error while storing config settings... ", ex);
		}
	}

	public void updateJabberHost(String jabberHost) throws Exception
	{
		try {
			this.jabberHost=jabberHost;
			bonitaConfig.setProperty("jabber.host",jabberHost);
			bonitaConfig.save(new FileOutputStream(this.bonitaHome+File.separator+".ant.properties"),null);
		}catch (Exception ex){
			throw new Exception("Error while storing config settings... ", ex);
		}
	}
	
	public void updateJabberPassword(String jabberPassword) throws Exception
	{
		try {
			this.jabberPassword=jabberPassword;
			bonitaConfig.setProperty("jabber.password",jabberPassword);
			bonitaConfig.save(new FileOutputStream(this.bonitaHome+File.separator+".ant.properties"),null);
		}catch (Exception ex){
			throw new Exception("Error while storing config settings... ", ex);
		}
	}
	
	public void updateJabberPort(int jabberPort) throws Exception
	{
		try {
			this.jabberPort=jabberPort;
			bonitaConfig.setProperty("jabber.port",String.valueOf(jabberPort));
			bonitaConfig.save(new FileOutputStream(this.bonitaHome+File.separator+".ant.properties"),null);
		}catch (Exception ex){
			throw new Exception("Error while storing config settings... ", ex);
		}
	}
		
	public void updateJabberUser(String jabberUser) throws Exception
	{
		try {
			this.jabberUser=jabberUser;
			bonitaConfig.setProperty("jabber.user",jabberUser);
			bonitaConfig.save(new FileOutputStream(this.bonitaHome+File.separator+".ant.properties"),null);
		}catch (Exception ex){
			throw new Exception("Error while storing config settings... ", ex);
		}
	}
	
	public void updateJms(boolean value) throws Exception 
	{
		try {
			this.jms=value;
			bonitaConfig.setProperty("bonita.Jms",new Boolean(value).toString());
			bonitaConfig.save(new FileOutputStream(this.bonitaHome+File.separator+".ant.properties"),null);
		}catch (Exception ex){
			throw new Exception("Error while storing config settings... ", ex);
		}
	}

	public void updateLogLevel(String value) throws Exception
	{
		try{
			if (value.equalsIgnoreCase(Constants.DEBUG) || value.equalsIgnoreCase(Constants.INFO) || value.equalsIgnoreCase(Constants.ERROR))
			{
				this.logLevel=value;
				log4jConfig.setProperty("log4j.logger.log",value+", bonitaLog");
				log4jConfig.save(new FileOutputStream(this.log4jConfigPath),null);
				log.setLevel(Level.toLevel(value));
			}
		}catch (Exception ex){
			throw new Exception("Error while storing config settings... ", ex);
		}
	}

	public void updateTraceLevel(String value) throws Exception
	{
		try{
			if (value.equalsIgnoreCase(Constants.DEBUG) || value.equalsIgnoreCase(Constants.INFO) || value.equalsIgnoreCase(Constants.ERROR))
			{
				this.traceLevel=value;
				log4jConfig.setProperty("log4j.logger.hero",value+", bonita");
				log4jConfig.save(new FileOutputStream(this.log4jConfigPath),null);
				trace.setLevel(Level.toLevel(value));
			}
		}catch (Exception ex){
			throw new Exception("Error while storing config settings... ", ex);
		}			
	}

	public void updateHistoric(String value) throws Exception
	{
		try{
			if (value.equalsIgnoreCase(Constants.TRANSFER) || value.equalsIgnoreCase(Constants.PURGE))
			{
				this.historic=value;
				bonitaConfig.setProperty("bonita.Historic",value);
				bonitaConfig.save(new FileOutputStream(this.bonitaHome+File.separator+".ant.properties"),null);
			}
		}catch (Exception ex){
			throw new Exception("Error while storing config settings... ", ex);
		}
	}
}
